const patterns = [
	{
		patterns: [
			{
				include: "#comment-tag"
			}
		],
		begin: "/\\*",
		name: "comment.block.postcss",
		end: "\\*/"
	},
	{
		include: "#double-slash"
	},
	{
		include: "#double-quoted"
	},
	{
		include: "#single-quoted"
	},
	{
		include: "#interpolation"
	},
	{
		include: "#placeholder-selector"
	},
	{
		include: "#variable"
	},
	{
		include: "#variable-root-css"
	},
	{
		include: "#numeric"
	},
	{
		include: "#unit"
	},
	{
		include: "#flag"
	},
	{
		include: "#dotdotdot"
	},
	{
		captures: {
			"0": {
				name: "keyword.control.at-rule.css.postcss"
			}
		},
		begin: "@include",
		name: "support.function.name.postcss.library",
		end: "(?=\\n|\\(|{|;)"
	},
	{
		captures: {
			"0": {
				name: "keyword.control.at-rule.css.postcss"
			}
		},
		patterns: [
			{
				name: "entity.name.function",
				match: "[\\w-]+"
			}
		],
		begin: "@mixin|@function",
		name: "support.function.name.postcss.no-completions",
		end: "$\\n?|(?=\\(|{)"
	},
	{
		name: "string.quoted.double.css.postcss",
		match: "(?<=@import)\\s[\\w/.*-]+"
	},
	{
		begin: "@",
		name: "keyword.control.at-rule.css.postcss",
		end: "$\\n?|\\s(?!(all|braille|embossed|handheld|print|projection|screen|speech|tty|tv|if|only|not)(\\s|,))|(?=;)"
	},
	{
		patterns: [
			{
				include: "#interpolation"
			},
			{
				include: "#pseudo-class"
			}
		],
		begin: "#",
		name: "entity.other.attribute-name.id.css.postcss",
		end: "$\\n?|(?=\\s|,|;|\\(|\\)|\\.|\\[|{|>)"
	},
	{
		patterns: [
			{
				include: "#interpolation"
			},
			{
				include: "#pseudo-class"
			}
		],
		begin: "\\.|(?<=&)(-|_)",
		name: "entity.other.attribute-name.class.css.postcss",
		end: "$\\n?|(?=\\s|,|;|\\(|\\)|\\[|{|>)"
	},
	{
		patterns: [
			{
				include: "#double-quoted"
			},
			{
				include: "#single-quoted"
			},
			{
				name: "keyword.other.regex.postcss",
				match: "\\^|\\$|\\*|~"
			}
		],
		begin: "\\[",
		name: "entity.other.attribute-selector.postcss",
		end: "\\]"
	},
	{
		name: "entity.other.attribute-name.pseudo-class.css.postcss",
		match: "(?<=\\]|\\)|not\\(|\\*|>|>\\s):[a-z:-]+|(::|:-)[a-z:-]+"
	},
	{
		patterns: [
			{
				include: "#double-slash"
			},
			{
				include: "#double-quoted"
			},
			{
				include: "#single-quoted"
			},
			{
				include: "#interpolation"
			},
			{
				include: "#variable"
			},
			{
				include: "#rgb-value"
			},
			{
				include: "#numeric"
			},
			{
				include: "#unit"
			},
			{
				include: "#flag"
			},
			{
				include: "#function"
			},
			{
				include: "#function-content"
			},
			{
				include: "#function-content-var"
			},
			{
				include: "#operator"
			},
			{
				include: "#parent-selector"
			},
			{
				include: "#property-value"
			}
		],
		begin: ":",
		name: "meta.property-list.css.postcss",
		end: "$\\n?|(?=;|\\s\\(|and\\(|{|}|\\),)"
	},
	{
		include: "#rgb-value"
	},
	{
		include: "#function"
	},
	{
		include: "#function-content"
	},
	{
		patterns: [
			{
				include: "#interpolation"
			},
			{
				include: "#pseudo-class"
			}
		],
		begin: "(?<!\\-|\\()\\b(a|abbr|acronym|address|applet|area|article|aside|audio|b|base|big|blockquote|body|br|button|canvas|caption|cite|code|col|colgroup|datalist|dd|del|details|dfn|dialog|div|dl|dt|em|embed|eventsource|fieldset|figure|figcaption|footer|form|frame|frameset|(h[1-6])|head|header|hgroup|hr|html|i|iframe|img|input|ins|kbd|label|legend|li|link|map|mark|menu|meta|meter|nav|noframes|noscript|object|ol|optgroup|option|output|p|param|picture|pre|progress|q|samp|script|section|select|small|source|span|strike|strong|style|sub|summary|sup|table|tbody|td|textarea|tfoot|th|thead|time|title|tr|tt|ul|var|video|main|svg|rect|ruby|center|circle|ellipse|line|polyline|polygon|path|text|u|x)\\b(?!-|\\)|:\\s)|&",
		name: "entity.name.tag.css.postcss.symbol",
		end: "(?=\\s|,|;|\\(|\\)|\\.|\\[|{|>|-|_)"
	},
	{
		include: "#operator"
	},
	{
		name: "support.type.property-name.css.postcss",
		match: "[a-z-]+((?=:|#{))"
	},
	{
		include: "#reserved-words"
	},
	{
		include: "#property-value"
	}
];
const name = "postcss";
const repository = {
	"reserved-words": {
		name: "support.type.property-name.css.postcss",
		match: "\\b(false|from|in|not|null|through|to|true)\\b"
	},
	"double-quoted": {
		patterns: [
			{
				include: "#quoted-interpolation"
			}
		],
		begin: "\"",
		name: "string.quoted.double.css.postcss",
		end: "\""
	},
	operator: {
		name: "keyword.operator.postcss",
		match: "\\+|\\s-\\s|\\s-(?=\\$)|(?<=\\()-(?=\\$)|\\s-(?=\\()|\\*|/|%|=|!|<|>|~"
	},
	"function-content": {
		name: "string.quoted.double.css.postcss",
		match: "(?<=url\\(|format\\(|attr\\().+?(?=\\))"
	},
	"double-slash": {
		patterns: [
			{
				include: "#comment-tag"
			}
		],
		begin: "//",
		name: "comment.line.postcss",
		end: "$"
	},
	numeric: {
		name: "constant.numeric.css.postcss",
		match: "(-|\\.)?[0-9]+(\\.[0-9]+)?"
	},
	"variable-root-css": {
		name: "variable.parameter.postcss",
		match: "(?<!&)--[\\w-]+"
	},
	"function": {
		name: "support.function.name.postcss",
		match: "(?<=[\\s|\\(|,|:])(?!url|format|attr)[\\w-][\\w-]*(?=\\()"
	},
	"rgb-value": {
		name: "constant.other.color.rgb-value.css.postcss",
		match: "(#)([0-9a-fA-F]{3}|[0-9a-fA-F]{6})\\b"
	},
	"comment-tag": {
		patterns: [
			{
				name: "comment.tag.postcss",
				match: "[\\w-]+"
			}
		],
		begin: "{{",
		name: "comment.tags.postcss",
		end: "}}"
	},
	interpolation: {
		patterns: [
			{
				include: "#variable"
			},
			{
				include: "#numeric"
			},
			{
				include: "#operator"
			},
			{
				include: "#unit"
			},
			{
				include: "#double-quoted"
			},
			{
				include: "#single-quoted"
			}
		],
		begin: "#{",
		name: "support.function.interpolation.postcss",
		end: "}"
	},
	unit: {
		name: "keyword.other.unit.css.postcss",
		match: "(?<=[\\d]|})(ch|cm|deg|dpcm|dpi|dppx|em|ex|grad|Hz|in|kHz|mm|ms|pc|pt|px|rad|rem|s|turn|vh|vmax|vmin|vw|%)"
	},
	"function-content-var": {
		name: "variable.parameter.postcss",
		match: "(?<=var\\()[\\w-]+(?=\\))"
	},
	dotdotdot: {
		name: "variable.other",
		match: "\\.{3}"
	},
	variable: {
		name: "variable.parameter.postcss",
		match: "\\$[\\w-]+"
	},
	"single-quoted": {
		patterns: [
			{
				include: "#quoted-interpolation"
			}
		],
		begin: "'",
		name: "string.quoted.single.css.postcss",
		end: "'"
	},
	"quoted-interpolation": {
		patterns: [
			{
				include: "#variable"
			},
			{
				include: "#numeric"
			},
			{
				include: "#operator"
			},
			{
				include: "#unit"
			}
		],
		begin: "#{",
		name: "support.function.interpolation.postcss",
		end: "}"
	},
	"pseudo-class": {
		name: "entity.other.attribute-name.pseudo-class.css.postcss",
		match: ":[a-z:-]+"
	},
	"property-value": {
		name: "meta.property-value.css.postcss, support.constant.property-value.css.postcss",
		match: "[\\w-]+"
	},
	"placeholder-selector": {
		begin: "(?<!\\d)%(?!\\d)",
		name: "entity.other.attribute-name.placeholder-selector.postcss",
		end: "$\\n?|\\s|(?=;|{)"
	},
	flag: {
		name: "keyword.other.important.css.postcss",
		match: "!(important|default|optional|global)"
	},
	"parent-selector": {
		name: "entity.name.tag.css.postcss",
		match: "&"
	}
};
const foldingStartMarker = "/\\*|^#|^\\*|^\\b|^\\.";
const foldingStopMarker = "\\*/|^\\s*$";
const fileTypes = [
	"pcss",
	"postcss"
];
const uuid = "90DAEA60-88AA-11E2-9E96-0800200C9A66";
const scopeName = "source.css.postcss";
const postcss_tmLanguage = {
	patterns: patterns,
	name: name,
	repository: repository,
	foldingStartMarker: foldingStartMarker,
	foldingStopMarker: foldingStopMarker,
	fileTypes: fileTypes,
	uuid: uuid,
	scopeName: scopeName
};

export { postcss_tmLanguage as default, fileTypes, foldingStartMarker, foldingStopMarker, name, patterns, repository, scopeName, uuid };
